**********************
Supporting information
**********************

Acknowledging MARXS
-------------------

If you use MARXS for work/research presented in a publication (whether
directly, or as a dependency to another package), we recommend and encourage
a citation of the `paper <https://arxiv.org/pdf/1710.05226.pdf>`_ (`ADS <https://ui.adsabs.harvard.edu/#abs/2017AJ....154..243G/abstract>`_ - `bibtex <http://adsabs.harvard.edu/cgi-bin/nph-bib_query?bibcode=2017AJ....154..243G&data_type=BIBTEX>`_).

Each released MARXS version is also assigned a DOI from Zenodo, where the DOI `10.5281/zenodo.592393 <https://doi.org/10.5281/zenodo.592393>`_ always points to the last released version.

MARXS makes use of a number of Python packages and your work would not be possible without them. The use of those packages should also be acknowledged, too, to be fair to their authors and to encourage ongoing development. In particular, see:

  - `Citations for numpy <https://www.scipy.org/citing.html>`_
  - `Astropy reference <http://www.astropy.org/acknowledging.html>`_
  - `Mayavi reference <https://docs.enthought.com/mayavi/mayavi/misc.html#citing-mayavi>`_ (for 3D plotting).

We thank the authors and contributors for those packages for their work!


Reporting bugs
--------------
Please report bugs in the `issue tracker <https://github.com/Chandra-MARX/marxs/issues>`_ of the project.


Getting support
---------------
You can post a questions in the `issue tracker <https://github.com/Chandra-MARX/marxs/issues>`_ of the project.
